summaryrefslogtreecommitdiffstats
path: root/module/plugins/hoster/PornhostCom.py
diff options
context:
space:
mode:
Diffstat (limited to 'module/plugins/hoster/PornhostCom.py')
-rw-r--r--module/plugins/hoster/PornhostCom.py26
1 files changed, 13 insertions, 13 deletions
diff --git a/module/plugins/hoster/PornhostCom.py b/module/plugins/hoster/PornhostCom.py
index 7520e261f..6901ae689 100644
--- a/module/plugins/hoster/PornhostCom.py
+++ b/module/plugins/hoster/PornhostCom.py
@@ -31,39 +31,39 @@ class PornhostCom(Hoster):
#: Old interface
def download_html(self):
url = self.pyfile.url
- self.html = self.load(url)
+ self.data = self.load(url)
def get_file_url(self):
"""
Returns the absolute downloadable filepath
"""
- if not self.html:
+ if not self.data:
self.download_html()
- url = re.search(r'download this file</label>.*?<a href="(.*?)"', self.html)
+ url = re.search(r'download this file</label>.*?<a href="(.*?)"', self.data)
if url is None:
- url = re.search(r'"(http://dl\d+\.pornhost\.com/files/.*?/.*?/.*?/.*?/.*?/.*?\..*?)"', self.html)
+ url = re.search(r'"(http://dl\d+\.pornhost\.com/files/.*?/.*?/.*?/.*?/.*?/.*?\..*?)"', self.data)
if url is None:
- url = re.search(r'width: 894px; height: 675px">.*?<img src="(.*?)"', self.html)
+ url = re.search(r'width: 894px; height: 675px">.*?<img src="(.*?)"', self.data)
if url is None:
url = re.search(r'"http://file\d+\.pornhost\.com/\d+/.*?"',
self.html) #@TODO: fix this one since it doesn't match
return url.group(1)
def get_file_name(self):
- if not self.html:
+ if not self.data:
self.download_html()
- name = re.search(r'<title>pornhost\.com - free file hosting with a twist - gallery(.*?)</title>', self.html)
+ name = re.search(r'<title>pornhost\.com - free file hosting with a twist - gallery(.*?)</title>', self.data)
if name is None:
- name = re.search(r'id="url" value="http://www\.pornhost\.com/(.*?)/"', self.html)
+ name = re.search(r'id="url" value="http://www\.pornhost\.com/(.*?)/"', self.data)
if name is None:
- name = re.search(r'<title>pornhost\.com - free file hosting with a twist -(.*?)</title>', self.html)
+ name = re.search(r'<title>pornhost\.com - free file hosting with a twist -(.*?)</title>', self.data)
if name is None:
- name = re.search(r'"http://file\d+\.pornhost\.com/.*?/(.*?)"', self.html)
+ name = re.search(r'"http://file\d+\.pornhost\.com/.*?/(.*?)"', self.data)
name = name.group(1).strip() + ".flv"
@@ -74,10 +74,10 @@ class PornhostCom(Hoster):
"""
Returns True or False
"""
- if not self.html:
+ if not self.data:
self.download_html()
- if re.search(r'gallery not found|You will be redirected to', self.html):
+ if re.search(r'gallery not found|You will be redirected to', self.data):
return False
else:
return True
@@ -31,39 +31,39 @@ class PornhostCom(Hoster):
if url is None:
url = re.search(r'"http://file\d+\.pornhost\.com/\d+/.*?"',
- self.html) #@TODO: fix this one since it doesn't match
+ self.data) #@TODO: fix this one since it doesn't match
return url.group(1)
def get_file_name(self):